@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * dictlex_dialog.c - dialog for displaying a dictlex module
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -308,7 +308,9 @@ void gui_create_dictlex_dialog(DIALOG_DATA *dlg)
 	GtkWidget *btnSyncDL;
 	//      GtkWidget *label205;
 	GtkWidget *frameDictHTML;
+#ifndef USE_WEBKIT2
 	GtkWidget *scrolledwindowDictHTML;
+#endif
 	GtkWidget *scrolledwindow;
 	//      GtkWidget *label;
 	GtkListStore *model;
@@ -350,7 +352,7 @@ void gui_create_dictlex_dialog(DIALOG_DATA *dlg)
 	gtk_button_set_relief(GTK_BUTTON(btnSyncDL), GTK_RELIEF_NONE);
 
 	tmp_toolbar_icon =
-#ifdef HAVE_GTK_310
+#if GTK_CHECK_VERSION(3, 10, 0)
 	    gtk_image_new_from_icon_name("gtk-refresh",
 					 GTK_ICON_SIZE_BUTTON);
 #else
@@ -382,7 +384,7 @@ void gui_create_dictlex_dialog(DIALOG_DATA *dlg)
 	dlg->listview =
 	    gtk_tree_view_new_with_model(GTK_TREE_MODEL(model));
 	gtk_widget_show(dlg->listview);
-#ifndef HAVE_GTK_310
+#if !GTK_CHECK_VERSION(3, 10, 0)
 	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(dlg->listview), TRUE);
 #endif
 	gtk_container_add(GTK_CONTAINER(scrolledwindow), dlg->listview);
@@ -395,6 +397,7 @@ void gui_create_dictlex_dialog(DIALOG_DATA *dlg)
 	gtk_widget_show(frameDictHTML);
 	gtk_paned_pack2(GTK_PANED(hpaned7), frameDictHTML, TRUE, TRUE);
 
+#ifndef USE_WEBKIT2
 	scrolledwindowDictHTML = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindowDictHTML);
 	gtk_container_add(GTK_CONTAINER(frameDictHTML),
@@ -405,13 +408,17 @@ void gui_create_dictlex_dialog(DIALOG_DATA *dlg)
 	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
 					    scrolledwindowDictHTML,
 					    settings.shadow_type);
+#endif
 
 	dlg->html =
 	    GTK_WIDGET(XIPHOS_HTML_NEW((DIALOG_DATA *)dlg, TRUE,
 				       DIALOG_DICTIONARY_TYPE));
-
+#ifdef USE_WEBKIT2
+	gtk_container_add(GTK_CONTAINER(frameDictHTML), dlg->html);
+#else
 	gtk_container_add(GTK_CONTAINER(scrolledwindowDictHTML),
 			  dlg->html);
+#endif
 	gtk_widget_show(dlg->html);
 	g_signal_connect((gpointer)dlg->html,
 			 "popupmenu_requested",
