@@ -114,8 +114,13 @@ on_help_contents_activate(GtkMenuItem *menuitem, gpointer user_data)
 	g_free(help_file);
 #else
 	GError *error = NULL;
+#if GTK_CHECK_VERSION(3, 22, 0)
+	gtk_show_uri_on_window(NULL, "ghelp:xiphos", gtk_get_current_event_time(),
+		     &error);
+#else
 	gtk_show_uri(NULL, "ghelp:xiphos", gtk_get_current_event_time(),
 		     &error);
+#endif
 	if (error != NULL) {
 		XI_warning(("%s", error->message));
 		g_error_free(error);
@@ -735,12 +740,12 @@ on_open_session_activate(GtkMenuItem *menuitem, gpointer user_data)
 		}
 	}
 
-	dialog = gtk_file_chooser_dialog_new("Open Session",
+	dialog = gtk_file_chooser_dialog_new(_("Open Session"),
 					     NULL,
 					     GTK_FILE_CHOOSER_ACTION_OPEN,
 #if GTK_CHECK_VERSION(3, 10, 0)
-					     "_Cancel",
-					     GTK_RESPONSE_CANCEL, "_Open",
+					     _("_Cancel"),
+					     GTK_RESPONSE_CANCEL, _("_Open"),
 					     GTK_RESPONSE_ACCEPT,
 #else
 					     GTK_STOCK_CANCEL,
