@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * main_window.c - main window gui
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -456,7 +456,7 @@ static gboolean on_configure_event(GtkWidget *widget,
 	settings.app_x = x;
 	settings.app_y = y;
 
-#ifdef HAVE_GTK_312
+#if GTK_CHECK_VERSION(3, 12, 0)
 	sprintf(layout, "%d", gtk_window_is_maximized(GTK_WINDOW(widgets.app)));
 	xml_set_value("Xiphos", "layout", "maximized", layout);
 #endif
@@ -684,16 +684,19 @@ static gboolean on_vbox1_key_press_event(GtkWidget *widget, GdkEventKey *event,
 	case XK_L:
 		if (state == GDK_CONTROL_MASK) // Ctrl-L  verse entry
 			gtk_widget_grab_focus(navbar_versekey.lookup_entry);
+		else if (state == GDK_MOD1_MASK) // Alt-L  lemma
+			kbd_toggle_option((main_check_for_global_option(sM, "ThMLLemma") ||
+					   main_check_for_global_option(sM, "OSISLemma")),
+					  "Lemmas");
 		break;
 
 	case XK_m:
 	case XK_M:
 		if (state == GDK_MOD1_MASK) // Alt-M morph
 		{
-			kbd_toggle_option((main_check_for_global_option(sM, "GBFMorph") || main_check_for_global_option(sM,
-															"ThMLMorph") ||
-					   main_check_for_global_option(sM,
-									"OSISMorph")),
+			kbd_toggle_option((main_check_for_global_option(sM, "GBFMorph") ||
+					   main_check_for_global_option(sM, "ThMLMorph") ||
+					   main_check_for_global_option(sM, "OSISMorph")),
 					  "Morphological Tags");
 		}
 		break;
@@ -706,7 +709,8 @@ static gboolean on_vbox1_key_press_event(GtkWidget *widget, GdkEventKey *event,
 			access_on_down_eventbox_button_release_event(CHAPTER_BUTTON);
 		else if (state == GDK_SHIFT_MASK) // N book
 			access_on_down_eventbox_button_release_event(BOOK_BUTTON);
-		else if (state == (GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SHIFT_MASK)) { // BSP transient navigate
+		else if (state == (GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SHIFT_MASK)) {
+			// BSP transient navigate
 			if (biblesync_active_xmit_allowed()) {
 				biblesync_prep_and_xmit(sM, sV);
 				gui_set_statusbar(_("BibleSync: Current navigation sent."));
@@ -771,8 +775,10 @@ static gboolean on_vbox1_key_press_event(GtkWidget *widget, GdkEventKey *event,
 
 	case XK_t:
 	case XK_T:
-		if (state == GDK_CONTROL_MASK) // open a new tab
+		if (state == GDK_CONTROL_MASK) // Ctrl-T open a new tab
 			on_notebook_main_new_tab_clicked(NULL, NULL);
+		else if (state == GDK_MOD1_MASK) // Alt-T transliteration
+			kbd_toggle_option(true, "Transliteration");
 		break;
 
 	case XK_z:
@@ -785,10 +791,12 @@ static gboolean on_vbox1_key_press_event(GtkWidget *widget, GdkEventKey *event,
 		if (state == (GDK_CONTROL_MASK | GDK_SHIFT_MASK))
 			new_base_font_size(TRUE);
 		break;
+
 	case XK_minus: // Ctrl-Minus  Decrease base font size
 		if (state == GDK_CONTROL_MASK)
 			new_base_font_size(FALSE);
 		break;
+
 	case XK_0: // Ctrl-0 (zero)  Neutralize base font size.
 		if (state == GDK_CONTROL_MASK) {
 			settings.base_font_size = 1;
@@ -813,10 +821,12 @@ static gboolean on_vbox1_key_press_event(GtkWidget *widget, GdkEventKey *event,
 		if (state == 0)
 			on_help_contents_activate(NULL, NULL);
 		break;
+
 	case XK_F2: // F2 preferences
 		if (state == 0)
 			on_preferences_activate(NULL, NULL);
 		break;
+
 	case XK_F3: // F3 search
 		if (state == 0)
 			main_open_search_dialog();
@@ -824,6 +834,7 @@ static gboolean on_vbox1_key_press_event(GtkWidget *widget, GdkEventKey *event,
 			gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_sidebar),
 						      2);
 		break;
+
 	case XK_F4: // F4 module manager
 		if (state == 0)
 			on_module_manager_activate(NULL, NULL);
@@ -832,13 +843,20 @@ static gboolean on_vbox1_key_press_event(GtkWidget *widget, GdkEventKey *event,
 								    ((PASSAGE_TAB_INFO *)
 								     cur_passage_tab)->page_widget));
 		break;
+
 	case XK_F10: // Shift-F10 bible module right click
 		if (state == GDK_SHIFT_MASK)
 			gui_menu_popup(NULL, sM, NULL);
 		/* FIXME: needs the html widget as first pram */
 		break;
+
+	case XK_F11: // F11 open current bible in separate window, maximized.
+		if (state == 0)
+			main_dialogs_open(sM, NULL, TRUE);
+		break;
 	}
-	XI_message(("on_vbox1_key_press_event\nkeycode: %d, keysym: %0x, state: %d", event->hardware_keycode, event->keyval, state));
+	XI_message(("on_vbox1_key_press_event\nkeycode: %d, keysym: %0x, state: %d",
+		    event->hardware_keycode, event->keyval, state));
 	return FALSE;
 }
 
@@ -879,7 +897,9 @@ void create_mainwindow(void)
 	GtkWidget *hbox25;
 	GtkWidget *tab_button_icon;
 	GtkWidget *label;
+#ifndef USE_WEBKIT2
 	GtkWidget *scrolledwindow;
+#endif
 	GtkWidget *box_book;
 	GdkPixbuf *pixbuf;
 	/*
@@ -896,301 +916,247 @@ void create_mainwindow(void)
 
 	widgets.studypad_dialog = NULL;
 
-	widgets.app = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_title(GTK_WINDOW(widgets.app),
-			     _("Xiphos - Bible Study Software"));
+	/* A rough scektch of the main window (widgets.app) and it's children
+	 *                widgets.app
+	 *                     |
+	 *                  vbox_gs
+	 *                     |
+	 *                  +--|----+
+	 *                  |       |
+	 *                 menu   hbox25
+	 *                           |
+	 *                     widgets.epaned
+	 *                         |
+	 *                 widgets.vboxMain
+	 *                 |              |
+	 *           widgets.hboxtb   widgets.page
+	 *                            |         |
+	 *                     widgets.hpaned  nav_toolbar
+	 *                     |            |
+	 *              widgets.vpaned---+  +----------------------------widgets.vpaned2---------------+
+	 *               |               |                                      |                      |
+	 * widgets.vbox_previewer   widgets.vbox_text              widgets.notebook_comm_book   widgets.box_dict
+	 *                               |                         |                       |
+	 *                widgets.notebook_bible_parallel   widgets.box_comm            box_book
+	 *                               |
+	 *                     widgets.notebook_text
+	 *
+	 */
 
-	g_object_set_data(G_OBJECT(widgets.app),
-			  "widgets.app", widgets.app);
-	gtk_widget_set_size_request(widgets.app, 680, 425);
+	// The toplevel Xiphos window
+	widgets.app = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title(GTK_WINDOW(widgets.app), _("Xiphos - Bible Study Software"));
+	g_object_set_data(G_OBJECT(widgets.app), "widgets.app", widgets.app);
+	gtk_window_set_default_size(GTK_WINDOW(widgets.app), 680, 425);
 	gtk_widget_set_can_focus(widgets.app, 1);
 	gtk_window_set_resizable(GTK_WINDOW(widgets.app), TRUE);
 
+	// The app icon.
+	// FIXME:: This should be a big copy of the logo because GTK does the scaling (GTK 3.16?)
 	imagename = image_locator("gs2-48x48.png");
 	pixbuf = gdk_pixbuf_new_from_file(imagename, NULL);
 	g_free(imagename);
 	gtk_window_set_icon(GTK_WINDOW(widgets.app), pixbuf);
 
+	// The main box for our toplevel window.
 	UI_VBOX(vbox_gs, FALSE, 0);
 	gtk_widget_show(vbox_gs);
 	gtk_container_add(GTK_CONTAINER(widgets.app), vbox_gs);
 
+	// Add the main menu.
 	menu = gui_create_main_menu();
-
 	gtk_box_pack_start(GTK_BOX(vbox_gs), menu, FALSE, TRUE, 0);
 
+	// Another box
 	UI_HBOX(hbox25, FALSE, 0);
 	gtk_widget_show(hbox25);
 	gtk_box_pack_start(GTK_BOX(vbox_gs), hbox25, TRUE, TRUE, 0);
 
-	/**widgets.epaned********/
+	// widgets.epaned
 	widgets.epaned = UI_HPANE();
 	gtk_widget_show(widgets.epaned);
-#ifdef HAVE_GTK_314
-	gtk_container_set_border_width(GTK_CONTAINER(widgets.epaned), 0);
-#else
+#if !GTK_CHECK_VERSION(3, 14, 0)
 	gtk_container_set_border_width(GTK_CONTAINER(widgets.epaned), 4);
 #endif
 	gtk_box_pack_start(GTK_BOX(hbox25), widgets.epaned, TRUE, TRUE, 0);
-
+	// Another box
 	UI_VBOX(widgets.vboxMain, FALSE, 0);
 	gtk_widget_show(widgets.vboxMain);
 	gtk_paned_pack2(GTK_PANED(widgets.epaned), widgets.vboxMain, TRUE, TRUE);
-#ifdef HAVE_GTK_314
-	gtk_container_set_border_width(GTK_CONTAINER(widgets.vboxMain), 0);
-#else
+#if !GTK_CHECK_VERSION(3, 14, 0)
 	gtk_container_set_border_width(GTK_CONTAINER(widgets.vboxMain), 2);
 #endif
 
 	/*
-	 * notebook to have separate passages opened at once
-	 * the passages are not actually open but are switched
-	 * between similar to bookmarks
+	 * Notebook to have separate passages opened at once the passages are not
+	 * actually open but are switched between similar to bookmarks
 	 */
 	UI_HBOX(widgets.hboxtb, FALSE, 0);
 	if (settings.browsing)
 		gtk_widget_show(widgets.hboxtb);
-	gtk_box_pack_start(GTK_BOX(widgets.vboxMain), widgets.hboxtb,
-			   FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(widgets.vboxMain), widgets.hboxtb, FALSE, FALSE, 0);
 
 	widgets.button_new_tab = gtk_button_new();
-	//don't show button here in case !settings.browsing
+	// Don't show button here in case !settings.browsing
 
-	tab_button_icon =
-#ifdef HAVE_GTK_310
-	    gtk_image_new_from_icon_name("tab-new-symbolic",
-					 GTK_ICON_SIZE_SMALL_TOOLBAR);
+#if GTK_CHECK_VERSION(3, 10, 0)
+	tab_button_icon = gtk_image_new_from_icon_name("tab-new-symbolic", GTK_ICON_SIZE_SMALL_TOOLBAR);
 #else
-	    gtk_image_new_from_stock(GTK_STOCK_ADD,
-				     GTK_ICON_SIZE_SMALL_TOOLBAR);
+	tab_button_icon = gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_SMALL_TOOLBAR);
 #endif
 
 	gtk_widget_show(tab_button_icon);
-	gtk_container_add(GTK_CONTAINER(widgets.button_new_tab),
-			  tab_button_icon);
-	gtk_button_set_relief(GTK_BUTTON(widgets.button_new_tab),
-			      GTK_RELIEF_NONE);
-	gtk_box_pack_start(GTK_BOX(widgets.hboxtb), widgets.button_new_tab,
-			   FALSE, FALSE, 0);
-	gtk_widget_set_tooltip_text(widgets.button_new_tab,
-				    _("Open a new tab"));
+	gtk_container_add(GTK_CONTAINER(widgets.button_new_tab), tab_button_icon);
+	gtk_button_set_relief(GTK_BUTTON(widgets.button_new_tab), GTK_RELIEF_NONE);
+	gtk_box_pack_start(GTK_BOX(widgets.hboxtb), widgets.button_new_tab, FALSE, FALSE, 0);
+	gtk_widget_set_tooltip_text(widgets.button_new_tab, _("Open a new tab"));
 
 	widgets.notebook_main = gtk_notebook_new();
 	gtk_widget_show(widgets.notebook_main);
-	gtk_box_pack_start(GTK_BOX(widgets.hboxtb),
-			   widgets.notebook_main, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(widgets.hboxtb), widgets.notebook_main, TRUE, TRUE, 0);
 	gtk_widget_set_size_request(widgets.notebook_main, -1, 25);
-	gtk_notebook_set_scrollable(GTK_NOTEBOOK(widgets.notebook_main),
-				    TRUE);
+	gtk_notebook_set_scrollable(GTK_NOTEBOOK(widgets.notebook_main), TRUE);
 	gtk_notebook_popup_enable(GTK_NOTEBOOK(widgets.notebook_main));
-	gtk_notebook_set_show_border(GTK_NOTEBOOK(widgets.notebook_main),
-				     FALSE);
-	/* main passage tabbed notebook end */
+	gtk_notebook_set_show_border(GTK_NOTEBOOK(widgets.notebook_main), FALSE);
+	// Main passage tabbed notebook end
 
+	// Another box
 	UI_VBOX(widgets.page, FALSE, 0);
 	gtk_widget_show(widgets.page);
-	gtk_box_pack_start(GTK_BOX(widgets.vboxMain), widgets.page, TRUE,
-			   TRUE, 0);
-	/*
-	 * nav toolbar
-	 */
-	nav_toolbar = gui_navbar_versekey_new();
-	gtk_box_pack_start(GTK_BOX(widgets.page), nav_toolbar, FALSE,
-			   FALSE, 0);
-	/*
-	 * end nav toolbar
-	 */
+	gtk_box_pack_start(GTK_BOX(widgets.vboxMain), widgets.page, TRUE, TRUE, 0);
 
-	/**widgets.hpaned********/
+	//nav toolbar
+	nav_toolbar = gui_navbar_versekey_new();
+	gtk_box_pack_start(GTK_BOX(widgets.page), nav_toolbar, FALSE, FALSE, 0);
+
+	// widgets.hpaned
 	widgets.hpaned = UI_HPANE();
 	gtk_widget_show(widgets.hpaned);
-	gtk_box_pack_start(GTK_BOX(widgets.page), widgets.hpaned, TRUE,
-			   TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(widgets.page), widgets.hpaned, TRUE, TRUE, 0);
 
-	/**widgets.vpaned********/
+	// widgets.vpaned
 	widgets.vpaned = UI_VPANE();
 	gtk_widget_show(widgets.vpaned);
 	gtk_widget_set_size_request(widgets.vpaned, 50, -1);
-	gtk_paned_pack1(GTK_PANED(widgets.hpaned), widgets.vpaned, TRUE,
-			FALSE);
+	gtk_paned_pack1(GTK_PANED(widgets.hpaned), widgets.vpaned, TRUE, FALSE);
 
+	// widgets.vpaned2
 	widgets.vpaned2 = UI_VPANE();
-	gtk_widget_show(widgets.vpaned2);
 	gtk_widget_set_size_request(widgets.vpaned2, 50, -1);
-	gtk_paned_pack2(GTK_PANED(widgets.hpaned), widgets.vpaned2, TRUE,
-			FALSE);
 
-	/**widgets.hpaned********/
+	// widgets.vbox_text
 	UI_VBOX(widgets.vbox_text, FALSE, 0);
 	gtk_widget_show(widgets.vbox_text);
-	gtk_paned_pack1(GTK_PANED(widgets.vpaned),
-			widgets.vbox_text, TRUE, TRUE);
+	gtk_paned_pack1(GTK_PANED(widgets.vpaned), widgets.vbox_text, TRUE, TRUE);
 
-	/*
-	 * bible/parallel notebook
-	 */
+	// Bible/parallel notebook
 	widgets.notebook_bible_parallel = gtk_notebook_new();
 	gtk_widget_show(widgets.notebook_bible_parallel);
-	gtk_box_pack_start(GTK_BOX(widgets.vbox_text),
-			   widgets.notebook_bible_parallel, TRUE, TRUE, 0);
-	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(widgets.notebook_bible_parallel),
-				 GTK_POS_BOTTOM);
-	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(widgets.notebook_bible_parallel),
-				   TRUE);
-	gtk_notebook_set_show_border(GTK_NOTEBOOK(widgets.notebook_bible_parallel),
-				     FALSE);
-	gtk_container_set_border_width(GTK_CONTAINER(widgets.notebook_bible_parallel),
-				       1);
+	gtk_box_pack_start(GTK_BOX(widgets.vbox_text), widgets.notebook_bible_parallel, TRUE, TRUE, 0);
+	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(widgets.notebook_bible_parallel), GTK_POS_BOTTOM);
+	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(widgets.notebook_bible_parallel), TRUE);
+	gtk_notebook_set_show_border(GTK_NOTEBOOK(widgets.notebook_bible_parallel), FALSE);
+	gtk_container_set_border_width(GTK_CONTAINER(widgets.notebook_bible_parallel), 1);
 
-	g_signal_connect(G_OBJECT(widgets.notebook_bible_parallel),
-			 "change-current-page",
-			 G_CALLBACK(on_notebook_bible_parallel_switch_page), NULL);
-	/*
-	 * text notebook
-	 */
+	g_signal_connect(G_OBJECT(widgets.notebook_bible_parallel), "change-current-page", G_CALLBACK(on_notebook_bible_parallel_switch_page), NULL);
+
+	// Text notebook (The bible text show in the standard view)
 	widgets.notebook_text = gui_create_bible_pane();
-
-	gtk_container_add(GTK_CONTAINER(widgets.notebook_bible_parallel),
-			  widgets.notebook_text);
+	gtk_container_add(GTK_CONTAINER(widgets.notebook_bible_parallel), widgets.notebook_text);
 
 	label = gtk_label_new(_("Standard View"));
 	gtk_widget_show(label);
-	gtk_notebook_set_tab_label(GTK_NOTEBOOK(widgets.notebook_bible_parallel),
-				   gtk_notebook_get_nth_page(GTK_NOTEBOOK(widgets.notebook_bible_parallel),
-							     0),
-				   label);
+	gtk_notebook_set_tab_label(GTK_NOTEBOOK(widgets.notebook_bible_parallel), gtk_notebook_get_nth_page(GTK_NOTEBOOK(widgets.notebook_bible_parallel), 0), label);
 
-	/*
-	 * previewer
-	 */
+	// Another box (For the previewer?)
 	UI_VBOX(widgets.vbox_previewer, FALSE, 0);
 	gtk_widget_show(widgets.vbox_previewer);
-	gtk_container_set_border_width(GTK_CONTAINER(widgets.vbox_previewer), 1);
-	gtk_paned_pack2(GTK_PANED(widgets.vpaned), widgets.vbox_previewer,
-			TRUE, TRUE);
-
+	gtk_paned_pack2(GTK_PANED(widgets.vpaned), widgets.vbox_previewer, TRUE, TRUE);
 	gtk_container_set_border_width(GTK_CONTAINER(widgets.vbox_previewer), 2);
 
+#ifndef USE_WEBKIT2
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
-	gtk_box_pack_start(GTK_BOX(widgets.vbox_previewer), scrolledwindow,
-			   TRUE, TRUE, 0);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow),
-				       GTK_POLICY_NEVER,
-				       GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
-					    scrolledwindow,
-					    settings.shadow_type);
+	gtk_box_pack_start(GTK_BOX(widgets.vbox_previewer), scrolledwindow, TRUE, TRUE, 0);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *) scrolledwindow, settings.shadow_type);
+#endif
 	widgets.html_previewer_text = GTK_WIDGET(XIPHOS_HTML_NEW(NULL, FALSE, VIEWER_TYPE));
-	gtk_container_add(GTK_CONTAINER(scrolledwindow),
-			  widgets.html_previewer_text);
-
 	gtk_widget_show(widgets.html_previewer_text);
+#ifdef USE_WEBKIT2
+	gtk_box_pack_start(GTK_BOX(widgets.vbox_previewer), widgets.html_previewer_text, TRUE, TRUE, 0);
+#else
+	gtk_container_add(GTK_CONTAINER(scrolledwindow), widgets.html_previewer_text);
+#endif
 
-	/*
-	 * commentary/book notebook
-	 */
+	// Commentary/book notebook
 	widgets.notebook_comm_book = gtk_notebook_new();
 	gtk_widget_show(widgets.notebook_comm_book);
 
-	gtk_paned_pack1(GTK_PANED(widgets.vpaned2),
-			widgets.notebook_comm_book, TRUE, TRUE);
+	gtk_paned_pack1(GTK_PANED(widgets.vpaned2), widgets.notebook_comm_book, TRUE, TRUE);
 	gtk_container_set_border_width(GTK_CONTAINER(widgets.notebook_comm_book), 1);
 
-	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(widgets.notebook_comm_book),
-				 GTK_POS_BOTTOM);
+	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(widgets.notebook_comm_book), GTK_POS_BOTTOM);
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(widgets.notebook_comm_book), TRUE);
 	gtk_notebook_set_show_border(GTK_NOTEBOOK(widgets.notebook_comm_book), FALSE);
 
-	/*
-	 * commentary pane
-	 */
+	// Commentary pane
 	widgets.box_comm = gui_create_commentary_pane();
-
-	gtk_container_add(GTK_CONTAINER(widgets.notebook_comm_book),
-			  widgets.box_comm);
+	gtk_container_add(GTK_CONTAINER(widgets.notebook_comm_book), widgets.box_comm);
 
 	label = gtk_label_new(_("Commentary View"));
 	gtk_widget_show(label);
-	gtk_notebook_set_tab_label(GTK_NOTEBOOK(widgets.notebook_comm_book),
-				   gtk_notebook_get_nth_page(GTK_NOTEBOOK(widgets.notebook_comm_book),
-							     0),
-				   label);
+	gtk_notebook_set_tab_label(GTK_NOTEBOOK(widgets.notebook_comm_book), gtk_notebook_get_nth_page(GTK_NOTEBOOK(widgets.notebook_comm_book), 0), label);
 
-	/*
-	 * book pane
-	 */
+	// Book pane
 	box_book = gui_create_book_pane();
-	gtk_container_add(GTK_CONTAINER(widgets.notebook_comm_book),
-			  box_book);
+	gtk_container_add(GTK_CONTAINER(widgets.notebook_comm_book), box_book);
 
 	label = gtk_label_new(_("Book View"));
 	gtk_widget_show(label);
-	gtk_notebook_set_tab_label(GTK_NOTEBOOK(widgets.notebook_comm_book),
-				   gtk_notebook_get_nth_page(GTK_NOTEBOOK(widgets.notebook_comm_book),
-							     1),
-				   label);
+	gtk_notebook_set_tab_label(GTK_NOTEBOOK(widgets.notebook_comm_book), gtk_notebook_get_nth_page(GTK_NOTEBOOK(widgets.notebook_comm_book), 1), label);
 
-	/*
-	 * dict/lex
-	 */
+	// Dict/lex
 	widgets.box_dict = gui_create_dictionary_pane();
-	gtk_paned_pack2(GTK_PANED(widgets.vpaned2),
-			widgets.box_dict, TRUE, TRUE);
-	/*
-	 * end  dict/lex
-	 */
+	gtk_paned_pack2(GTK_PANED(widgets.vpaned2), widgets.box_dict, TRUE, TRUE);
 
+	// Statusbar
 	widgets.appbar = gtk_statusbar_new();
-
 	if (settings.statusbar) {
 		gtk_widget_show(widgets.appbar);
 	}
 
 #ifndef USE_GTK_3
-	gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(widgets.appbar),
-					  TRUE);
+	gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(widgets.appbar), TRUE);
 #endif
-	gtk_box_pack_start(GTK_BOX(vbox_gs), widgets.appbar, FALSE, TRUE,
-			   0);
+	gtk_box_pack_start(GTK_BOX(vbox_gs), widgets.appbar, FALSE, TRUE, 0);
 	gui_set_statusbar(_("Welcome to Xiphos"));
 
-	g_signal_connect((gpointer)vbox_gs, "key_press_event",
-			 G_CALLBACK(on_vbox1_key_press_event), NULL);
-	g_signal_connect((gpointer)vbox_gs, "key_release_event",
-			 G_CALLBACK(on_vbox1_key_release_event), NULL);
-
-	g_signal_connect(G_OBJECT(widgets.notebook_comm_book),
-			 "switch_page",
-			 G_CALLBACK(on_notebook_comm_book_switch_page), NULL);
-
-	g_signal_connect(G_OBJECT(widgets.app), "delete_event",
-			 G_CALLBACK(delete_event), NULL);
-
-	g_signal_connect((gpointer)widgets.app,
-			 "configure_event",
-			 G_CALLBACK(on_configure_event), NULL);
-	g_signal_connect(G_OBJECT(widgets.epaned),
-			 "button_release_event",
-			 G_CALLBACK(epaned_button_release_event),
-			 (gchar *)"epaned");
-	g_signal_connect(G_OBJECT(widgets.vpaned),
-			 "button_release_event",
-			 G_CALLBACK(epaned_button_release_event),
-			 (gchar *)"vpaned");
-	g_signal_connect(G_OBJECT(widgets.vpaned2),
-			 "button_release_event",
-			 G_CALLBACK(epaned_button_release_event),
-			 (gchar *)"vpaned2");
-	g_signal_connect(G_OBJECT(widgets.hpaned),
-			 "button_release_event",
-			 G_CALLBACK(epaned_button_release_event),
-			 (gchar *)"hpaned1");
-
+	gtk_paned_pack2(GTK_PANED(widgets.hpaned), widgets.vpaned2, TRUE, FALSE);
 	gtk_widget_grab_focus(navbar_versekey.lookup_entry);
 
-	gtk_window_set_default_size((GtkWindow *)widgets.app,
-				    settings.gs_width, settings.gs_height);
+	gtk_window_set_default_size((GtkWindow *)widgets.app, settings.gs_width, settings.gs_height);
+	gtk_widget_show_all(widgets.app);
+
+	/* must connect signals *after* instantiating window above, */
+	/* immediately above, otherwise window creation induces */
+	/* configure_event, wiping out user's saved geometry specs. */
+	/* *important*: drain gtk event queue first (i.e. sync). */
+
+	sync_windows();
+	g_signal_connect((gpointer)vbox_gs, "key_press_event", G_CALLBACK(on_vbox1_key_press_event), NULL);
+	g_signal_connect((gpointer)vbox_gs, "key_release_event", G_CALLBACK(on_vbox1_key_release_event), NULL);
+
+	g_signal_connect(G_OBJECT(widgets.notebook_comm_book), "switch_page", G_CALLBACK(on_notebook_comm_book_switch_page), NULL);
+
+	g_signal_connect(G_OBJECT(widgets.app), "delete_event", G_CALLBACK(delete_event), NULL);
+
+	g_signal_connect((gpointer)widgets.app, "configure_event", G_CALLBACK(on_configure_event), NULL);
+	g_signal_connect(G_OBJECT(widgets.epaned), "button_release_event", G_CALLBACK(epaned_button_release_event), (gchar *)"epaned");
+	g_signal_connect(G_OBJECT(widgets.vpaned), "button_release_event", G_CALLBACK(epaned_button_release_event), (gchar *)"vpaned");
+	g_signal_connect(G_OBJECT(widgets.vpaned2), "button_release_event", G_CALLBACK(epaned_button_release_event), (gchar *)"vpaned2");
+	g_signal_connect(G_OBJECT(widgets.hpaned), "button_release_event", G_CALLBACK(epaned_button_release_event), (gchar *)"hpaned1");
+
 	main_window_created = TRUE;
 }
 
