@@ -1318,7 +1318,7 @@ G_MODULE_EXPORT void on_rename_perscomm_activate(GtkMenuItem *menuitem,
 			_("Choose Commentary Name"));
 	info->label_top = workstr->str;
 	info->text1 = g_strdup(_("New Name"));
-	info->label1 = N_("Name: ");
+	info->label1 = _("Name: ");
 	info->ok = TRUE;
 	info->cancel = TRUE;
 
@@ -2026,8 +2026,12 @@ void gui_menu_popup(XiphosHtml *html, const gchar *mod_name,
 
 	menu = _create_popup_menu(html, mod_name, d);
 	if (menu)
+#if GTK_CHECK_VERSION(3, 22, 0)
+		gtk_menu_popup_at_pointer((GtkMenu *)menu, NULL);
+#else
 		gtk_menu_popup((GtkMenu *)menu, NULL, NULL, NULL, NULL, 2,
 			       gtk_get_current_event_time());
+#endif
 	else
 		gui_generic_warning(_("No module in this pane."));
 }
