@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * parallel_dialog.c - dialog for parallel in a tab
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -239,7 +239,9 @@ GtkWidget *_create_parallel_tab(void)
 {
 	GtkWidget *toolbar29;
 	GtkWidget *box_parallel_labels;
+#ifndef USE_WEBKIT2
 	GtkWidget *scrolled_window;
+#endif
 
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(widgets.notebook_bible_parallel),
 				   FALSE);
@@ -290,6 +292,7 @@ GtkWidget *_create_parallel_tab(void)
 	}
 #endif /* 0 */
 
+#ifndef USE_WEBKIT2
 	scrolled_window = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolled_window);
 	gtk_box_pack_start(GTK_BOX(parallel_vbox), scrolled_window, TRUE,
@@ -300,13 +303,17 @@ GtkWidget *_create_parallel_tab(void)
 	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
 					    scrolled_window,
 					    settings.shadow_type);
+#endif
 
 	widgets.html_parallel_dialog =
 	    GTK_WIDGET(XIPHOS_HTML_NEW(NULL, FALSE, PARALLEL_TYPE));
 	gtk_widget_show(widgets.html_parallel_dialog);
-
+#ifdef USE_WEBKIT2
+	gtk_box_pack_start(GTK_BOX(parallel_vbox), widgets.html_parallel_dialog, TRUE, TRUE, 0);
+#else
 	gtk_container_add(GTK_CONTAINER(scrolled_window),
 			  widgets.html_parallel_dialog);
+#endif
 
 	g_signal_connect((gpointer)widgets.html_parallel_dialog,
 			 "popupmenu_requested",
