@@ -122,6 +122,7 @@ struct _preferences_check_buttons
 	GtkWidget *bs_presence;
 	GtkWidget *bs_mismatch;
 	GtkWidget *bs_group_tab;
+	GtkWidget *bs_keyboard;
 	GtkWidget *bs_privacy;
 };
 
@@ -886,7 +887,8 @@ gchar *on_biblesync_obtain_passphrase()
  *   *((int*)user_data) is settings' bs_* bitflag.
  *
  * Description
- *   debug (packet dump), presence, mismatch, privacy, and group/tab.
+ *   handle toggle of these biblesync flags:
+ *   keyboard, privacy, presence, mismatch, debug (packet dump), group/tab.
  *
  * Return value
  *   void
@@ -949,6 +951,9 @@ on_radiobutton_biblesync_mode(GtkToggleButton *togglebutton,
 						     (settings.bs_mode == 3));
 		}
 
+		gtk_widget_set_sensitive(check_button.bs_keyboard,
+					 ((settings.bs_mode == 1) || (settings.bs_mode == 2)));
+
 		if (biblesync_personal()) {
 			gtk_widget_set_sensitive(check_button.bs_privacy, TRUE);
 			on_checkbutton_biblesync_toggled(GTK_TOGGLE_BUTTON(check_button.bs_privacy),
@@ -2213,10 +2218,14 @@ static void setup_check_buttons(void)
 				     settings.bs_mismatch);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button.bs_group_tab),
 				     settings.bs_group_tab);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button.bs_keyboard),
+				     settings.bs_keyboard);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button.bs_privacy),
 				     settings.bs_privacy);
 	gtk_widget_set_sensitive(check_button.bs_privacy,
 				 biblesync_personal());
+	gtk_widget_set_sensitive(check_button.bs_keyboard,
+				 ((settings.bs_mode == 1) || (settings.bs_mode == 2)));
 
 	/* mode */
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_button.bs_mode_off),
@@ -2294,6 +2303,9 @@ static void setup_check_buttons(void)
 	g_signal_connect(check_button.bs_group_tab, "toggled",
 			 G_CALLBACK(on_checkbutton_biblesync_toggled),
 			 &settings.bs_group_tab);
+	g_signal_connect(check_button.bs_keyboard, "toggled",
+			 G_CALLBACK(on_checkbutton_biblesync_toggled),
+			 &settings.bs_keyboard);
 	g_signal_connect(check_button.bs_privacy, "toggled",
 			 G_CALLBACK(on_checkbutton_biblesync_toggled),
 			 &settings.bs_privacy);
@@ -2968,6 +2980,7 @@ static void create_preferences_dialog(void)
 	check_button.bs_presence  = UI_GET_ITEM(gxml, "checkbutton_BSP_presence");
 	check_button.bs_mismatch  = UI_GET_ITEM(gxml, "checkbutton_BSP_mismatch");
 	check_button.bs_group_tab = UI_GET_ITEM(gxml, "checkbutton_BSP_group_tab");
+	check_button.bs_keyboard  = UI_GET_ITEM(gxml, "checkbutton_BSP_keyboard");
 	check_button.bs_privacy   = UI_GET_ITEM(gxml, "checkbutton_BSP_privacy");
 
 	radio_button.bs_mode_off      = UI_GET_ITEM(gxml, "radiobutton_BSP_off");
