@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * xiphos.c -
  *
- * Copyright (C) 2000-2015 Xiphos Developer Team
+ * Copyright (C) 2000-2017 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -234,6 +234,10 @@ void frontend_display(const char *tabs)
 		main_open_search_dialog();
 	if (settings.display_prefs)
 		gui_setup_preferences_dialog();
+	if (!settings.docked) {
+		settings.docked = TRUE;	/* momentary lie */
+		on_attach_detach_sidebar_activate(NULL, 0);
+	}
 
 	if (settings.showdevotional)
 		main_display_devotional();
