@@ -92,6 +92,21 @@ gboolean main_export_current_adv_search(GString *str, gboolean html, gboolean wi
 	gboolean ret = FALSE;
 	gchar *desc;
 
+	const gchar *search_string = gtk_entry_get_text(GTK_ENTRY(search1.search_entry));
+	gchar search_type[100];
+
+	g_strlcpy(search_type,
+		  (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(search1.rb_regexp))
+		   ? _("Regular expression")
+		   : (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(search1.rb_exact_phrase))
+		      ? _("Exact phrase")
+		      : (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(search1.rb_words))
+			 ? _("Multi-word")
+			 : (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(search1.rb_optimized))
+			    ? _("Optimized (\"lucene\")")
+			    : _("Attribute"))))), 99);
+
+
 	tmp = g_list_first(list_for_bookmarking);
 	if (html)
 		str = g_string_append(str, "<html><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" /></head><body>");
@@ -107,9 +122,14 @@ gboolean main_export_current_adv_search(GString *str, gboolean html, gboolean wi
 				ret = TRUE;
 				if (first_entry) {
 					if (html)
-						g_string_printf(verse_string, "<ul><b>%s</b>", list_item->module);
+						g_string_printf(verse_string,
+								"<b>%s</b><br/>%s<br/><br/><ul><b>%s</b>",
+								search_string, search_type,
+								list_item->module);
 					else
-						g_string_printf(verse_string, "%s\n", list_item->module);
+						g_string_printf(verse_string, "%s\n%s\n\n%s\n",
+								search_string, search_type,
+								list_item->module);
 					first_entry = FALSE;
 					str = g_string_append(str, verse_string->str);
 				} else {
@@ -842,8 +862,10 @@ void main_selection_finds_list_changed(GtkTreeSelection *
 	path_str = gtk_tree_path_to_string(path);
 	XI_message(("\npath: %s\ntext: %s", path_str, text));
 	tmp = g_list_nth(list_of_finds, atoi(path_str));
-	tmp = (GList *)tmp->data;
-	add_module_finds(tmp);
+	if (tmp) {
+		tmp = (GList *)tmp->data;
+		add_module_finds(tmp);
+	}
 
 	if (text)
 		g_free(text);
@@ -1068,14 +1090,15 @@ void main_comboboxentry2_changed(GtkComboBox *combobox, gpointer user_data)
 
 static void check_search_global_options(void)
 {
-	set_search_global_option("Strong's Numbers",
-				 gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(search1.cb_include_strongs)));
-
-	set_search_global_option("Morphological Tags",
-				 gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(search1.cb_include_morphs)));
-
-	set_search_global_option("Footnotes",
-				 gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(search1.cb_include_footnotes)));
+	if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(search1.rb_exact_phrase)))
+	{
+		set_search_global_option("Strong's Numbers",
+			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(search1.cb_include_strongs)));
+		set_search_global_option("Morphological Tags",
+			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(search1.cb_include_morphs)));
+		set_search_global_option("Footnotes",
+			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(search1.cb_include_footnotes)));
+	}
 }
 
 /******************************************************************************
