@@ -1234,6 +1234,8 @@ void main_display_dictionary(const char *mod_name,
 void main_display_bible(const char *mod_name,
 			const char *key)
 {
+	gchar *bs_key = g_strdup(key);	// avoid tab data corruption problem.
+
 	/* keeps us out of a crash causing loop */
 	extern guint scroll_adj_signal;
 	extern GtkAdjustment *adjustment;
@@ -1372,7 +1374,10 @@ void main_display_bible(const char *mod_name,
 			gui_keep_parallel_dialog_in_sync();
 	}
 
-	biblesync_prep_and_xmit(mod_name, key);
+	// multicast now, iff user has not asked for keyboard-only xmit.
+	if (!settings.bs_keyboard)
+		biblesync_prep_and_xmit(mod_name, bs_key);
+	g_free(bs_key);
 
 	if (adjustment)
 		g_signal_handler_unblock(adjustment, scroll_adj_signal);
@@ -1621,8 +1626,8 @@ char *main_get_mod_config_file(const char *module_name,
 			name += "/mods.d/";
 			name += ent;
 			SWConfig *config = new SWConfig(name.c_str());
-			if (config->Sections.find(module_name) !=
-			    config->Sections.end()) {
+			if (config->getSections().find(module_name) !=
+			    config->getSections().end()) {
 				gchar *ret_name = g_strdup(ent);
 				g_dir_close(dir);
 				delete config;
